# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 64.4.0-v202407221832
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class FormulaUpgradeOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'after_formula': 'str',
        'before_formula': 'str',
        'changes': 'list[FormulaUpgradeChangeV1]'
    }

    attribute_map = {
        'after_formula': 'afterFormula',
        'before_formula': 'beforeFormula',
        'changes': 'changes'
    }

    def __init__(self, after_formula=None, before_formula=None, changes=None):
        """
        FormulaUpgradeOutputV1 - a model defined in Swagger
        """

        self._after_formula = None
        self._before_formula = None
        self._changes = None

        if after_formula is not None:
          self.after_formula = after_formula
        if before_formula is not None:
          self.before_formula = before_formula
        if changes is not None:
          self.changes = changes

    @property
    def after_formula(self):
        """
        Gets the after_formula of this FormulaUpgradeOutputV1.
        The resulting changed formula

        :return: The after_formula of this FormulaUpgradeOutputV1.
        :rtype: str
        """
        return self._after_formula

    @after_formula.setter
    def after_formula(self, after_formula):
        """
        Sets the after_formula of this FormulaUpgradeOutputV1.
        The resulting changed formula

        :param after_formula: The after_formula of this FormulaUpgradeOutputV1.
        :type: str
        """

        self._after_formula = after_formula

    @property
    def before_formula(self):
        """
        Gets the before_formula of this FormulaUpgradeOutputV1.
        The original input formula

        :return: The before_formula of this FormulaUpgradeOutputV1.
        :rtype: str
        """
        return self._before_formula

    @before_formula.setter
    def before_formula(self, before_formula):
        """
        Sets the before_formula of this FormulaUpgradeOutputV1.
        The original input formula

        :param before_formula: The before_formula of this FormulaUpgradeOutputV1.
        :type: str
        """

        self._before_formula = before_formula

    @property
    def changes(self):
        """
        Gets the changes of this FormulaUpgradeOutputV1.
        Details about the specific changes

        :return: The changes of this FormulaUpgradeOutputV1.
        :rtype: list[FormulaUpgradeChangeV1]
        """
        return self._changes

    @changes.setter
    def changes(self, changes):
        """
        Sets the changes of this FormulaUpgradeOutputV1.
        Details about the specific changes

        :param changes: The changes of this FormulaUpgradeOutputV1.
        :type: list[FormulaUpgradeChangeV1]
        """

        self._changes = changes

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, FormulaUpgradeOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 64.4.0-v202407221832
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ItemFinderOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cron_schedule': 'list[str]',
        'description': 'str',
        'effective_permissions': 'PermissionsV1',
        'enabled': 'bool',
        'executor_id': 'str',
        'finder_configurations': 'list[ItemFinderConfigurationV1]',
        'id': 'str',
        'is_archived': 'bool',
        'is_redacted': 'bool',
        'last_run_warnings': 'list[str]',
        'name': 'str',
        'status_message': 'str',
        'translation_key': 'str',
        'type': 'str'
    }

    attribute_map = {
        'cron_schedule': 'cronSchedule',
        'description': 'description',
        'effective_permissions': 'effectivePermissions',
        'enabled': 'enabled',
        'executor_id': 'executorId',
        'finder_configurations': 'finderConfigurations',
        'id': 'id',
        'is_archived': 'isArchived',
        'is_redacted': 'isRedacted',
        'last_run_warnings': 'lastRunWarnings',
        'name': 'name',
        'status_message': 'statusMessage',
        'translation_key': 'translationKey',
        'type': 'type'
    }

    def __init__(self, cron_schedule=None, description=None, effective_permissions=None, enabled=None, executor_id=None, finder_configurations=None, id=None, is_archived=False, is_redacted=False, last_run_warnings=None, name=None, status_message=None, translation_key=None, type=None):
        """
        ItemFinderOutputV1 - a model defined in Swagger
        """

        self._cron_schedule = None
        self._description = None
        self._effective_permissions = None
        self._enabled = None
        self._executor_id = None
        self._finder_configurations = None
        self._id = None
        self._is_archived = None
        self._is_redacted = None
        self._last_run_warnings = None
        self._name = None
        self._status_message = None
        self._translation_key = None
        self._type = None

        if cron_schedule is not None:
          self.cron_schedule = cron_schedule
        if description is not None:
          self.description = description
        if effective_permissions is not None:
          self.effective_permissions = effective_permissions
        if enabled is not None:
          self.enabled = enabled
        if executor_id is not None:
          self.executor_id = executor_id
        if finder_configurations is not None:
          self.finder_configurations = finder_configurations
        if id is not None:
          self.id = id
        if is_archived is not None:
          self.is_archived = is_archived
        if is_redacted is not None:
          self.is_redacted = is_redacted
        if last_run_warnings is not None:
          self.last_run_warnings = last_run_warnings
        if name is not None:
          self.name = name
        if status_message is not None:
          self.status_message = status_message
        if translation_key is not None:
          self.translation_key = translation_key
        if type is not None:
          self.type = type

    @property
    def cron_schedule(self):
        """
        Gets the cron_schedule of this ItemFinderOutputV1.
        The item finder's check interval(s) as a list of cron expressions (see https://www.quartz-scheduler.org/documentation/quartz-2.3.0/tutorials/crontrigger.html)

        :return: The cron_schedule of this ItemFinderOutputV1.
        :rtype: list[str]
        """
        return self._cron_schedule

    @cron_schedule.setter
    def cron_schedule(self, cron_schedule):
        """
        Sets the cron_schedule of this ItemFinderOutputV1.
        The item finder's check interval(s) as a list of cron expressions (see https://www.quartz-scheduler.org/documentation/quartz-2.3.0/tutorials/crontrigger.html)

        :param cron_schedule: The cron_schedule of this ItemFinderOutputV1.
        :type: list[str]
        """

        self._cron_schedule = cron_schedule

    @property
    def description(self):
        """
        Gets the description of this ItemFinderOutputV1.
        Clarifying information or other plain language description of this item

        :return: The description of this ItemFinderOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ItemFinderOutputV1.
        Clarifying information or other plain language description of this item

        :param description: The description of this ItemFinderOutputV1.
        :type: str
        """

        self._description = description

    @property
    def effective_permissions(self):
        """
        Gets the effective_permissions of this ItemFinderOutputV1.

        :return: The effective_permissions of this ItemFinderOutputV1.
        :rtype: PermissionsV1
        """
        return self._effective_permissions

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions):
        """
        Sets the effective_permissions of this ItemFinderOutputV1.

        :param effective_permissions: The effective_permissions of this ItemFinderOutputV1.
        :type: PermissionsV1
        """

        self._effective_permissions = effective_permissions

    @property
    def enabled(self):
        """
        Gets the enabled of this ItemFinderOutputV1.
        Whether this item finder is enabled or not

        :return: The enabled of this ItemFinderOutputV1.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this ItemFinderOutputV1.
        Whether this item finder is enabled or not

        :param enabled: The enabled of this ItemFinderOutputV1.
        :type: bool
        """
        if enabled is None:
            raise ValueError("Invalid value for `enabled`, must not be `None`")

        self._enabled = enabled

    @property
    def executor_id(self):
        """
        Gets the executor_id of this ItemFinderOutputV1.
        The ID of the user that runs the job of finding the items. The permissions of this user will be used to determine what items can be read.

        :return: The executor_id of this ItemFinderOutputV1.
        :rtype: str
        """
        return self._executor_id

    @executor_id.setter
    def executor_id(self, executor_id):
        """
        Sets the executor_id of this ItemFinderOutputV1.
        The ID of the user that runs the job of finding the items. The permissions of this user will be used to determine what items can be read.

        :param executor_id: The executor_id of this ItemFinderOutputV1.
        :type: str
        """
        if executor_id is None:
            raise ValueError("Invalid value for `executor_id`, must not be `None`")

        self._executor_id = executor_id

    @property
    def finder_configurations(self):
        """
        Gets the finder_configurations of this ItemFinderOutputV1.
        The list of configurations for finding items

        :return: The finder_configurations of this ItemFinderOutputV1.
        :rtype: list[ItemFinderConfigurationV1]
        """
        return self._finder_configurations

    @finder_configurations.setter
    def finder_configurations(self, finder_configurations):
        """
        Sets the finder_configurations of this ItemFinderOutputV1.
        The list of configurations for finding items

        :param finder_configurations: The finder_configurations of this ItemFinderOutputV1.
        :type: list[ItemFinderConfigurationV1]
        """
        if finder_configurations is None:
            raise ValueError("Invalid value for `finder_configurations`, must not be `None`")

        self._finder_configurations = finder_configurations

    @property
    def id(self):
        """
        Gets the id of this ItemFinderOutputV1.
        The ID that can be used to interact with the item

        :return: The id of this ItemFinderOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ItemFinderOutputV1.
        The ID that can be used to interact with the item

        :param id: The id of this ItemFinderOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def is_archived(self):
        """
        Gets the is_archived of this ItemFinderOutputV1.
        Whether item is archived

        :return: The is_archived of this ItemFinderOutputV1.
        :rtype: bool
        """
        return self._is_archived

    @is_archived.setter
    def is_archived(self, is_archived):
        """
        Sets the is_archived of this ItemFinderOutputV1.
        Whether item is archived

        :param is_archived: The is_archived of this ItemFinderOutputV1.
        :type: bool
        """

        self._is_archived = is_archived

    @property
    def is_redacted(self):
        """
        Gets the is_redacted of this ItemFinderOutputV1.
        Whether item is redacted

        :return: The is_redacted of this ItemFinderOutputV1.
        :rtype: bool
        """
        return self._is_redacted

    @is_redacted.setter
    def is_redacted(self, is_redacted):
        """
        Sets the is_redacted of this ItemFinderOutputV1.
        Whether item is redacted

        :param is_redacted: The is_redacted of this ItemFinderOutputV1.
        :type: bool
        """

        self._is_redacted = is_redacted

    @property
    def last_run_warnings(self):
        """
        Gets the last_run_warnings of this ItemFinderOutputV1.
        The most recent list of warnings or errors that resulted from evaluating any of the finder configurations, such as items that failed to swap

        :return: The last_run_warnings of this ItemFinderOutputV1.
        :rtype: list[str]
        """
        return self._last_run_warnings

    @last_run_warnings.setter
    def last_run_warnings(self, last_run_warnings):
        """
        Sets the last_run_warnings of this ItemFinderOutputV1.
        The most recent list of warnings or errors that resulted from evaluating any of the finder configurations, such as items that failed to swap

        :param last_run_warnings: The last_run_warnings of this ItemFinderOutputV1.
        :type: list[str]
        """
        if last_run_warnings is None:
            raise ValueError("Invalid value for `last_run_warnings`, must not be `None`")

        self._last_run_warnings = last_run_warnings

    @property
    def name(self):
        """
        Gets the name of this ItemFinderOutputV1.
        The human readable name

        :return: The name of this ItemFinderOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ItemFinderOutputV1.
        The human readable name

        :param name: The name of this ItemFinderOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def status_message(self):
        """
        Gets the status_message of this ItemFinderOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation

        :return: The status_message of this ItemFinderOutputV1.
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """
        Sets the status_message of this ItemFinderOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation

        :param status_message: The status_message of this ItemFinderOutputV1.
        :type: str
        """

        self._status_message = status_message

    @property
    def translation_key(self):
        """
        Gets the translation_key of this ItemFinderOutputV1.
        The item's translation key, if any

        :return: The translation_key of this ItemFinderOutputV1.
        :rtype: str
        """
        return self._translation_key

    @translation_key.setter
    def translation_key(self, translation_key):
        """
        Sets the translation_key of this ItemFinderOutputV1.
        The item's translation key, if any

        :param translation_key: The translation_key of this ItemFinderOutputV1.
        :type: str
        """

        self._translation_key = translation_key

    @property
    def type(self):
        """
        Gets the type of this ItemFinderOutputV1.
        The type of the item

        :return: The type of this ItemFinderOutputV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ItemFinderOutputV1.
        The type of the item

        :param type: The type of this ItemFinderOutputV1.
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")

        self._type = type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ItemFinderOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 64.4.0-v202407221832
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class AuditOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'after_summary': 'str',
        'before_summary': 'str',
        'change_type': 'str',
        'item_id': 'str',
        'item_name': 'str',
        'item_type': 'str',
        'time_stamp': 'str',
        'user_id': 'str',
        'user_name': 'str'
    }

    attribute_map = {
        'after_summary': 'afterSummary',
        'before_summary': 'beforeSummary',
        'change_type': 'changeType',
        'item_id': 'itemId',
        'item_name': 'itemName',
        'item_type': 'itemType',
        'time_stamp': 'timeStamp',
        'user_id': 'userId',
        'user_name': 'userName'
    }

    def __init__(self, after_summary=None, before_summary=None, change_type=None, item_id=None, item_name=None, item_type=None, time_stamp=None, user_id=None, user_name=None):
        """
        AuditOutputV1 - a model defined in Swagger
        """

        self._after_summary = None
        self._before_summary = None
        self._change_type = None
        self._item_id = None
        self._item_name = None
        self._item_type = None
        self._time_stamp = None
        self._user_id = None
        self._user_name = None

        if after_summary is not None:
          self.after_summary = after_summary
        if before_summary is not None:
          self.before_summary = before_summary
        if change_type is not None:
          self.change_type = change_type
        if item_id is not None:
          self.item_id = item_id
        if item_name is not None:
          self.item_name = item_name
        if item_type is not None:
          self.item_type = item_type
        if time_stamp is not None:
          self.time_stamp = time_stamp
        if user_id is not None:
          self.user_id = user_id
        if user_name is not None:
          self.user_name = user_name

    @property
    def after_summary(self):
        """
        Gets the after_summary of this AuditOutputV1.
        A summary of the changed fields after the change was made.

        :return: The after_summary of this AuditOutputV1.
        :rtype: str
        """
        return self._after_summary

    @after_summary.setter
    def after_summary(self, after_summary):
        """
        Sets the after_summary of this AuditOutputV1.
        A summary of the changed fields after the change was made.

        :param after_summary: The after_summary of this AuditOutputV1.
        :type: str
        """

        self._after_summary = after_summary

    @property
    def before_summary(self):
        """
        Gets the before_summary of this AuditOutputV1.
        A summary of the changed fields before the change was made.

        :return: The before_summary of this AuditOutputV1.
        :rtype: str
        """
        return self._before_summary

    @before_summary.setter
    def before_summary(self, before_summary):
        """
        Sets the before_summary of this AuditOutputV1.
        A summary of the changed fields before the change was made.

        :param before_summary: The before_summary of this AuditOutputV1.
        :type: str
        """

        self._before_summary = before_summary

    @property
    def change_type(self):
        """
        Gets the change_type of this AuditOutputV1.
        The type of change that was made (Create, Update, or Delete).

        :return: The change_type of this AuditOutputV1.
        :rtype: str
        """
        return self._change_type

    @change_type.setter
    def change_type(self, change_type):
        """
        Sets the change_type of this AuditOutputV1.
        The type of change that was made (Create, Update, or Delete).

        :param change_type: The change_type of this AuditOutputV1.
        :type: str
        """
        allowed_values = ["CREATE", "UPDATE", "DELETE"]
        if change_type not in allowed_values:
            raise ValueError(
                "Invalid value for `change_type` ({0}), must be one of {1}"
                .format(change_type, allowed_values)
            )

        self._change_type = change_type

    @property
    def item_id(self):
        """
        Gets the item_id of this AuditOutputV1.
        The ID of the modified item.

        :return: The item_id of this AuditOutputV1.
        :rtype: str
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """
        Sets the item_id of this AuditOutputV1.
        The ID of the modified item.

        :param item_id: The item_id of this AuditOutputV1.
        :type: str
        """

        self._item_id = item_id

    @property
    def item_name(self):
        """
        Gets the item_name of this AuditOutputV1.
        The name of the modified item.

        :return: The item_name of this AuditOutputV1.
        :rtype: str
        """
        return self._item_name

    @item_name.setter
    def item_name(self, item_name):
        """
        Sets the item_name of this AuditOutputV1.
        The name of the modified item.

        :param item_name: The item_name of this AuditOutputV1.
        :type: str
        """

        self._item_name = item_name

    @property
    def item_type(self):
        """
        Gets the item_type of this AuditOutputV1.
        The type of the modified item.

        :return: The item_type of this AuditOutputV1.
        :rtype: str
        """
        return self._item_type

    @item_type.setter
    def item_type(self, item_type):
        """
        Sets the item_type of this AuditOutputV1.
        The type of the modified item.

        :param item_type: The item_type of this AuditOutputV1.
        :type: str
        """

        self._item_type = item_type

    @property
    def time_stamp(self):
        """
        Gets the time_stamp of this AuditOutputV1.
        The date and time when the change was made.

        :return: The time_stamp of this AuditOutputV1.
        :rtype: str
        """
        return self._time_stamp

    @time_stamp.setter
    def time_stamp(self, time_stamp):
        """
        Sets the time_stamp of this AuditOutputV1.
        The date and time when the change was made.

        :param time_stamp: The time_stamp of this AuditOutputV1.
        :type: str
        """

        self._time_stamp = time_stamp

    @property
    def user_id(self):
        """
        Gets the user_id of this AuditOutputV1.
        The ID of the user who made the change.

        :return: The user_id of this AuditOutputV1.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this AuditOutputV1.
        The ID of the user who made the change.

        :param user_id: The user_id of this AuditOutputV1.
        :type: str
        """

        self._user_id = user_id

    @property
    def user_name(self):
        """
        Gets the user_name of this AuditOutputV1.
        The username of the user who made the change.

        :return: The user_name of this AuditOutputV1.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """
        Sets the user_name of this AuditOutputV1.
        The username of the user who made the change.

        :param user_name: The user_name of this AuditOutputV1.
        :type: str
        """

        self._user_name = user_name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, AuditOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 64.4.0-v202407221832
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient
from ..models import *

class UnstableApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def get_cache(self, **kwargs):
        """
        Get raw cache data associated with the supplied cacheId.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_cache(cache_id=cache_id_value, start=start_value, exclusive_end=exclusive_end_value, metadata_only=metadata_only_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str cache_id: (required)
        :param str start: An 8601 timestamp corresponding to the key at the beginning of the query interval. (required)
        :param str exclusive_end: An 8601 timestamp corresponding to the key at the end of the query interval. (required)
        :param str max_datums: The maximum number of datums to retrieve from the persistent cache. If a request exceeds this value, the result will be truncated. Cannot be larger than: 1048576 unless `metadataOnly` is true.
        :param bool metadata_only: If set to true, the endpoint will only return cache record metadata (no decompression). (required)
        :param str override_timeout: A duration, in minutes, that should be used as a timeout for the GRPC connection. Default: 2 minutes.
        :return: DebugCacheBlockOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DebugCacheBlockOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_cache_with_http_info(**kwargs)
        else:
            (data) = self.get_cache_with_http_info(**kwargs)
            return data

    def get_cache_with_http_info(self, **kwargs):
        """
        Get raw cache data associated with the supplied cacheId.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_cache_with_http_info(cache_id=cache_id_value, start=start_value, exclusive_end=exclusive_end_value, metadata_only=metadata_only_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str cache_id: (required)
        :param str start: An 8601 timestamp corresponding to the key at the beginning of the query interval. (required)
        :param str exclusive_end: An 8601 timestamp corresponding to the key at the end of the query interval. (required)
        :param str max_datums: The maximum number of datums to retrieve from the persistent cache. If a request exceeds this value, the result will be truncated. Cannot be larger than: 1048576 unless `metadataOnly` is true.
        :param bool metadata_only: If set to true, the endpoint will only return cache record metadata (no decompression). (required)
        :param str override_timeout: A duration, in minutes, that should be used as a timeout for the GRPC connection. Default: 2 minutes.
        :return: DebugCacheBlockOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DebugCacheBlockOutputV1
        """

        all_params = ['cache_id', 'start', 'exclusive_end', 'max_datums', 'metadata_only', 'override_timeout']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_cache" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cache_id' is set
        if ('cache_id' not in params) or (params['cache_id'] is None):
            raise ValueError("Missing the required parameter `cache_id` when calling `get_cache`")
        # verify the required parameter 'start' is set
        if ('start' not in params) or (params['start'] is None):
            raise ValueError("Missing the required parameter `start` when calling `get_cache`")
        # verify the required parameter 'exclusive_end' is set
        if ('exclusive_end' not in params) or (params['exclusive_end'] is None):
            raise ValueError("Missing the required parameter `exclusive_end` when calling `get_cache`")
        # verify the required parameter 'metadata_only' is set
        if ('metadata_only' not in params) or (params['metadata_only'] is None):
            raise ValueError("Missing the required parameter `metadata_only` when calling `get_cache`")


        collection_formats = {}

        path_params = {}
        if 'cache_id' in params:
            path_params['cacheId'] = params['cache_id']

        query_params = []
        if 'start' in params:
            query_params.append(('start', params['start']))
        if 'exclusive_end' in params:
            query_params.append(('exclusiveEnd', params['exclusive_end']))
        if 'max_datums' in params:
            query_params.append(('maxDatums', params['max_datums']))
        if 'metadata_only' in params:
            query_params.append(('metadataOnly', params['metadata_only']))
        if 'override_timeout' in params:
            query_params.append(('overrideTimeout', params['override_timeout']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/cache/{cacheId}/blocks', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'DebugCacheBlockOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 64.4.0-v202407221832
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class TableColumnOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'type': 'str',
        'units': 'str'
    }

    attribute_map = {
        'name': 'name',
        'type': 'type',
        'units': 'units'
    }

    def __init__(self, name=None, type=None, units=None):
        """
        TableColumnOutputV1 - a model defined in Swagger
        """

        self._name = None
        self._type = None
        self._units = None

        if name is not None:
          self.name = name
        if type is not None:
          self.type = type
        if units is not None:
          self.units = units

    @property
    def name(self):
        """
        Gets the name of this TableColumnOutputV1.
        The name of the column

        :return: The name of this TableColumnOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TableColumnOutputV1.
        The name of the column

        :param name: The name of this TableColumnOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def type(self):
        """
        Gets the type of this TableColumnOutputV1.
        The type of the column. Valid values include 'string', 'number', and 'date'. Booleans are reported as 'number'

        :return: The type of this TableColumnOutputV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this TableColumnOutputV1.
        The type of the column. Valid values include 'string', 'number', and 'date'. Booleans are reported as 'number'

        :param type: The type of this TableColumnOutputV1.
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")

        self._type = type

    @property
    def units(self):
        """
        Gets the units of this TableColumnOutputV1.
        The units of the column. Only provided if type is 'number'

        :return: The units of this TableColumnOutputV1.
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """
        Sets the units of this TableColumnOutputV1.
        The units of the column. Only provided if type is 'number'

        :param units: The units of this TableColumnOutputV1.
        :type: str
        """

        self._units = units

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TableColumnOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 64.4.0-v202407221832
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ConditionNotificationOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'creator': 'IdentityPreviewV1',
        'enabled': 'bool',
        'id': 'str',
        'name': 'str',
        'workbooks': 'dict(str, str)'
    }

    attribute_map = {
        'creator': 'creator',
        'enabled': 'enabled',
        'id': 'id',
        'name': 'name',
        'workbooks': 'workbooks'
    }

    def __init__(self, creator=None, enabled=None, id=None, name=None, workbooks=None):
        """
        ConditionNotificationOutputV1 - a model defined in Swagger
        """

        self._creator = None
        self._enabled = None
        self._id = None
        self._name = None
        self._workbooks = None

        if creator is not None:
          self.creator = creator
        if enabled is not None:
          self.enabled = enabled
        if id is not None:
          self.id = id
        if name is not None:
          self.name = name
        if workbooks is not None:
          self.workbooks = workbooks

    @property
    def creator(self):
        """
        Gets the creator of this ConditionNotificationOutputV1.

        :return: The creator of this ConditionNotificationOutputV1.
        :rtype: IdentityPreviewV1
        """
        return self._creator

    @creator.setter
    def creator(self, creator):
        """
        Sets the creator of this ConditionNotificationOutputV1.

        :param creator: The creator of this ConditionNotificationOutputV1.
        :type: IdentityPreviewV1
        """

        self._creator = creator

    @property
    def enabled(self):
        """
        Gets the enabled of this ConditionNotificationOutputV1.
        Whether the associated condition monitor is enabled or not

        :return: The enabled of this ConditionNotificationOutputV1.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this ConditionNotificationOutputV1.
        Whether the associated condition monitor is enabled or not

        :param enabled: The enabled of this ConditionNotificationOutputV1.
        :type: bool
        """
        if enabled is None:
            raise ValueError("Invalid value for `enabled`, must not be `None`")

        self._enabled = enabled

    @property
    def id(self):
        """
        Gets the id of this ConditionNotificationOutputV1.
        ID of the associated condition monitor

        :return: The id of this ConditionNotificationOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ConditionNotificationOutputV1.
        ID of the associated condition monitor

        :param id: The id of this ConditionNotificationOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ConditionNotificationOutputV1.
        Notification name

        :return: The name of this ConditionNotificationOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ConditionNotificationOutputV1.
        Notification name

        :param name: The name of this ConditionNotificationOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def workbooks(self):
        """
        Gets the workbooks of this ConditionNotificationOutputV1.
        The workbooks that contain the conditions associated with the condition monitor

        :return: The workbooks of this ConditionNotificationOutputV1.
        :rtype: dict(str, str)
        """
        return self._workbooks

    @workbooks.setter
    def workbooks(self, workbooks):
        """
        Sets the workbooks of this ConditionNotificationOutputV1.
        The workbooks that contain the conditions associated with the condition monitor

        :param workbooks: The workbooks of this ConditionNotificationOutputV1.
        :type: dict(str, str)
        """
        if workbooks is None:
            raise ValueError("Invalid value for `workbooks`, must not be `None`")

        self._workbooks = workbooks

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ConditionNotificationOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 64.4.0-v202407221832
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class PermissionsV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'manage': 'bool',
        'read': 'bool',
        'write': 'bool'
    }

    attribute_map = {
        'manage': 'manage',
        'read': 'read',
        'write': 'write'
    }

    def __init__(self, manage=False, read=False, write=False):
        """
        PermissionsV1 - a model defined in Swagger
        """

        self._manage = None
        self._read = None
        self._write = None

        if manage is not None:
          self.manage = manage
        if read is not None:
          self.read = read
        if write is not None:
          self.write = write

    @property
    def manage(self):
        """
        Gets the manage of this PermissionsV1.

        :return: The manage of this PermissionsV1.
        :rtype: bool
        """
        return self._manage

    @manage.setter
    def manage(self, manage):
        """
        Sets the manage of this PermissionsV1.

        :param manage: The manage of this PermissionsV1.
        :type: bool
        """

        self._manage = manage

    @property
    def read(self):
        """
        Gets the read of this PermissionsV1.

        :return: The read of this PermissionsV1.
        :rtype: bool
        """
        return self._read

    @read.setter
    def read(self, read):
        """
        Sets the read of this PermissionsV1.

        :param read: The read of this PermissionsV1.
        :type: bool
        """

        self._read = read

    @property
    def write(self):
        """
        Gets the write of this PermissionsV1.

        :return: The write of this PermissionsV1.
        :rtype: bool
        """
        return self._write

    @write.setter
    def write(self, write):
        """
        Sets the write of this PermissionsV1.

        :param write: The write of this PermissionsV1.
        :type: bool
        """

        self._write = write

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PermissionsV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
